pub struct PromptBudget { /* private fields */ }Expand description
Exact byte and conservative token limits for one compiled prompt.
Implementations
Sourceimpl PromptBudget
impl PromptBudget
Sourcepub fn new(
max_bytes: usize,
max_estimated_tokens: usize,
) -> Result<Self, ContextError>
pub fn new( max_bytes: usize, max_estimated_tokens: usize, ) -> Result<Self, ContextError>
Creates non-zero bounded prompt limits.
Errors
Returns an error for zero values or limits above 16 MiB / safe integer.
Sourcepub const fn max_estimated_tokens(self) -> usize
pub const fn max_estimated_tokens(self) -> usize
Returns conservative estimated-token limit.